# MiCADO Client Library

A Python client library for MiCADO (github.com/micado-scale) to support the following:
- Create an ADT
- Deploy, update and delete an application in MiCADO
- Create and destroy a MiCADO node
